SystemOrganization addCategory: #'Seaside-Tools-Core'!

!GRPackage class methodsFor: '*seaside-tools-core' stamp: 'jf 6/23/2010 17:15'!
seasideToolsCore
	^ self new
		name: 'Seaside-Tools-Core';
		description: 'Administrative tools, useful to have for production and development environments.';
		addDependency: 'Seaside-Core';
		addDependency: 'Seaside-Component'; "only for deprecated class-side method extension"
		addDependency: 'Seaside-RenderLoop'; "for class references in WAAdmin"
		addDependency: 'Seaside-Session'; "for class reference in WAAdmin"
		url: #seasideUrl;
		yourself! !

!WARegistry class methodsFor: '*seaside-tools-core' stamp: 'jf 2/5/2010 16:27'!
clearAllHandlers
	self 
		greaseDeprecatedApi: 'WARegistry class>>#clearAllHandlers'
		details: 'Use WAAdmin class>>#clearSessions instead.'.
	^ WAAdmin clearSessions! !

!WARequestHandler class methodsFor: '*seaside-tools-core' stamp: 'lr 1/25/2010 23:31'!
register: aString 
	self 
		greaseDeprecatedApi: 'WARequestHandler class>>#register:'
		details: 'Use WAAdmin class>>#register:at:.'.
	^ WAAdmin 
		register: self
		at: aString! !

!WARequestHandler class methodsFor: '*seaside-tools-core' stamp: 'lr 1/25/2010 23:31'!
register: aString in: aDispatcher 
	self 
		greaseDeprecatedApi: 'WARequestHandler class>>#register:in:'
		details: 'Use WAAdmin class>>#register:at:in:.'.
	^ WAAdmin 
		register: self
		at: aString
		in: aDispatcher! !

!WAServerAdaptor class methodsFor: '*seaside-tools-core' stamp: 'lr 7/25/2011 19:03'!
default
	"Helper method that returns a single adaptor of this class from the default ServerManager.
	If there are no adaptors of this class registered, return nil. If there are multiple adaptors
	of this type, signal an error."
	
	| adaptors |
	adaptors := WAAdmin serverAdaptors select: [ :each | each isKindOf: self ].
	(adaptors size > 1) ifTrue: [ self error: 'You cannot use this convenience method when more than one adaptor of the same type are registered. Use WAServerManager or a graphical interface when dealing with multiple adaptors of the same type.' ].
	^ adaptors isEmpty
		ifTrue: [ nil ]
		ifFalse: [ adaptors first ]! !

!WAServerAdaptor class methodsFor: '*seaside-tools-core' stamp: 'jf 3/17/2009 15:03'!
start
	"Convenience method to start a single already registered adaptor of the type of the
	receiver."

	self default start! !

!WAServerAdaptor class methodsFor: '*seaside-tools-core' stamp: 'jf 3/17/2009 15:01'!
startOn: portInteger
	"Convenience method to start a single adaptor on the specified port. If an existing
	adaptor of this type is already registered, it will be restarted on the specified port."

	| adaptor |
	adaptor := self default.
	adaptor isNil
		ifFalse: [ adaptor stop; port: portInteger ]
		ifTrue: [ adaptor := self port: portInteger ].
	adaptor start! !

!WAServerAdaptor class methodsFor: '*seaside-tools-core' stamp: 'jf 3/17/2009 15:01'!
stop
	"Convenience method to stop a currently running adaptor of the type of the receiver
	as long as there is only one such adaptor currently registered."

	| default |
	default := self default.
	default isNil ifFalse: [ default stop ]! !

WAObject subclass: #WAAdmin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tools-Core'!

WAAdmin class
	instanceVariableNames: 'configuredApplicationDefaults configuredExceptionHandlingDefaults'!

WAAdmin class
	instanceVariableNames: 'configuredApplicationDefaults configuredExceptionHandlingDefaults'!

!WAAdmin class methodsFor: 'configuration' stamp: 'jf 3/16/2009 08:23'!
applicationDefaults
	| config |
	config := WASharedConfiguration named: 'Application Defaults'.
	(configuredApplicationDefaults ifNil: [ false ]) ifFalse: [
		self configureApplicationDefaults: config.
		configuredApplicationDefaults := true ].
	^ config! !

!WAAdmin class methodsFor: 'configuration' stamp: 'jf 3/16/2009 08:24'!
applicationExceptionHandlingDefaults
	| config |
	config := WASharedConfiguration named: 'Application Exception Handling Defaults'.
	(configuredExceptionHandlingDefaults ifNil: [ false ]) ifFalse: [
		self configureApplicationExceptionHandlingDefaults: config.
		configuredExceptionHandlingDefaults := true ].
	^ config! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 3/15/2009 18:22'!
clearAll
	self clearDefaultDispatcher.
	self clearConfigurationCaches.
	self clearSessions.! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 9/17/2008 20:58'!
clearConfigurationCaches
	WASystemConfiguration clearAllDescriptions! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 3/15/2009 18:22'!
clearDefaultDispatcher
	WADispatcher resetDefault! !

!WAAdmin class methodsFor: 'development' stamp: 'jf 2/5/2010 15:56'!
clearSessions
	self defaultServerManager adaptors do: [ :adaptor |
		adaptor requestHandler withDescendantsDo: [ :handler |
			handler isApplication ifTrue: [ handler clear ] ] ]! !

!WAAdmin class methodsFor: 'initialization' stamp: 'jf 3/16/2009 08:25'!
configureApplicationDefaults: aSharedConfiguration
	"WARenderLoopConfiguration is added by default because most users will use WASession and the Render Loop."
	(aSharedConfiguration parents includes: WARenderLoopConfiguration instance) ifFalse: [
		aSharedConfiguration addParent: WARenderLoopConfiguration instance ]! !

!WAAdmin class methodsFor: 'initialization' stamp: 'jgf 3/17/2009 08:06'!
configureApplicationExceptionHandlingDefaults: aSharedConfiguration
	(aSharedConfiguration parents includes: WAExceptionFilterConfiguration instance) ifFalse: [
		aSharedConfiguration addParent: WAExceptionFilterConfiguration instance ]! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 3/4/2009 10:59'!
configureNewApplication: anApplication
	| filter |
	anApplication configuration
		removeParent: WAApplicationConfiguration instance; "make the chain slightly cleaner"
		addParent: WARenderLoopConfiguration instance;
		addParent: self applicationDefaults.
		
	filter := WAExceptionFilter new.
	filter configuration addParent: self applicationExceptionHandlingDefaults.
	anApplication addFilter: filter! !

!WAAdmin class methodsFor: 'configuration' stamp: 'jf 10/26/2008 12:19'!
defaultDispatcher
	^ WADispatcher default! !

!WAAdmin class methodsFor: 'server adaptors' stamp: 'yann.monclair 9/5/2009 18:02'!
defaultServerManager
	"Return the default server manager"
	
	^ WAServerManager default! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 3/15/2009 19:54'!
register: aComponentClass asApplicationAt: aString
	"Use this to programatically register a component as an application."
	| application |
	application := self register: WAApplication at: aString.
	self configureNewApplication: application.
	application preferenceAt: #rootClass put: aComponentClass.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 9/30/2009 00:19'!
register: aComponentClass asApplicationAt: aString user: user password: password 
	"Like #register:asApplicationAt: but additionally adds password protection."
	| application |
	application := self 
		register: aComponentClass
		asApplicationAt: aString.
	application configuration addParent: WAAuthConfiguration instance.
	application 
		preferenceAt: #login
		put: user.
	application 
		preferenceAt: #passwordHash
		put: (GRPlatform current secureHashFor: password).
	application addFilter: WAAuthenticationFilter new.
	^ application! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 10/26/2008 12:19'!
register: anEntryPointClass at: aString
	^ self register: anEntryPointClass at: aString in: self defaultDispatcher! !

!WAAdmin class methodsFor: 'registration' stamp: 'jf 12/29/2009 14:06'!
register: aRequestHandlerClass at: aString in: aDispatcher
	| path dispatcher |
	path := aString subStrings: '/'.
	dispatcher := path allButLast
		inject: aDispatcher
		into: [ :result :each |
			result handlers 
				at: each
				ifAbsent: [ result register: WADispatcher new at: each ] ].
	^ dispatcher register: aRequestHandlerClass new at: path last! !

!WAAdmin class methodsFor: 'server adaptors' stamp: 'jf 3/17/2009 15:13'!
serverAdaptors
	"Return a collection of Server Adaptors that are currently registered in the default Server Manager."
	^ self defaultServerManager adaptors! !

!WAAdmin class methodsFor: 'registration' stamp: 'lr 1/20/2010 13:52'!
unregister: aString
	"Unregister the application aString in the default dispatcher."

	^ self unregister: aString in: self defaultDispatcher! !

!WAAdmin class methodsFor: 'registration' stamp: 'TestRunner 1/20/2010 14:03'!
unregister: aString in: aDispatcher
	"Unregister the application aString in aDispatcher."

	| path dispatcher |
	path := aString subStrings: '/'.
	dispatcher := path
		inject: aDispatcher
		into: [ :result :each |
			result handlers
				at: each
				ifAbsent: [ ^ nil ] ].
	^ dispatcher parent
		unregister: dispatcher! !

!WAComponent class methodsFor: '*seaside-tools-core' stamp: 'jf 9/30/2009 01:02'!
registerAsApplication: aString 
	self 
		greaseDeprecatedApi: 'WAComponent class>>#registerAsApplication:'
		details: 'Use WAAdmin class>>#register:asApplicationAt:.'.
	^ WAAdmin 
		register: self
		asApplicationAt: aString! !
